@@ -48,8 +48,6 @@ __all__ = [
     'list_floating_ips',
 
     'nuke_network',
-    'chi_wizard_create_network',
-    'chi_wizard_delete_network',
 ]
 
 PUBLIC_NETWORK = 'public'
@@ -181,7 +179,7 @@ def list_networks() -> 'list[dict]':
     Returns:
         A list of all the found networks.
     """
-    return neutron().list_networks()
+    return neutron().list_networks()["networks"]
 
 
 ##########
@@ -277,7 +275,7 @@ def list_subnets() -> 'list[dict]':
     Returns:
         A list of all the found subnets.
     """
-    return neutron().list_subnets()
+    return neutron().list_subnets()["subnets"]
 
 
 ########
@@ -373,7 +371,7 @@ def list_ports() -> 'list[dict]':
     Returns:
         A list of all the found ports.
     """
-    return neutron().list_ports()
+    return neutron().list_ports()["ports"]
 
 
 ##########
@@ -455,7 +453,7 @@ def list_routers() -> 'list[dict]':
     Returns:
         A list of all the found routers.
     """
-    return neutron().list_routers()
+    return neutron().list_routers()["routers"]
 
 
 ####################
@@ -484,6 +482,7 @@ def add_routes_to_router(router_id, routes):
             to consist of items with a 'destination' and 'nexthop' key, e.g.:
 
             .. code-block:: python
+
                 [
                    {'destination': '10.0.0.0/24', 'nexthop': '10.0.0.1'},
                    {'destination': '10.0.1.0/24', 'nexthop': '10.0.1.1'}
@@ -517,6 +516,7 @@ def remove_routes_from_router(router_id, routes):
             to consist of items with a 'destination' and 'nexthop' key, e.g.:
 
             .. code-block:: python
+
                 [
                    {'destination': '10.0.0.0/24', 'nexthop': '10.0.0.1'},
                    {'destination': '10.0.1.0/24', 'nexthop': '10.0.1.1'}
@@ -676,7 +676,7 @@ def list_floating_ips() -> 'list[dict]':
     Returns:
         A list of all the found floating ips.
     """
-    return neutron().list_floatingips()
+    return neutron().list_floatingips()["floatingips"]
 
 
 def nuke_network(network_name):
@@ -692,7 +692,8 @@ def nuke_network(network_name):
 
     This function performs all of those steps for you.
 
-    .. info::
+    .. note::
+
        This function will not work well for very advance networks, perhaps
        those connected to multiple routers. You should perform your own cleanup
        if your network's subnets are attached to multiple routers.
